from pyzotero import zotero
from datetime import date


def getDataFromWebPage(item):
    # Title

    title = item['data']['title']

    # Authors

    if 'creators' in item['data'].keys():
        authors = []
        for author in item['data']['creators']:
            authors.append(author['lastName'])
        authors = ';'.join(authors)
    else:
        authors = ''

    # Source

    source = item['data']['url']

    # Abstract
    if 'abstractNote' in item['data'].keys():
        abstract = item['data']['abstractNote']
    else:
        abstract = ''

    # Date

    if 'date' in item['data'].keys() and item['data']['date'] != '':
        pdate = item['data']['date'].split('-')
        pdate[2] = pdate[2].split('T')[0]
        pdate = '\t'.join(pdate)
    else:
        pdate = str(date.today().year) + '\t1\t1'

    abstract = abstract.encode(encoding='UTF-8', errors='ignore').decode(
        "utf-8").replace('\t', '').replace('"', '').replace('\n', '')
    title = title.encode(encoding='UTF-8', errors='ignore').decode(
        "utf-8").replace('\t', '').replace('"', '').replace('\n', '')
    source = source.encode(encoding='UTF-8', errors='ignore').decode(
        "utf-8").replace('\t', '').replace('"', '').replace('\n', '').replace('\n', '')

    # Output
    return str(title) + "\t" + source + "\t" + str(pdate) + "\t" + abstract + "\t" + authors + "\t" + str(1) + "\n"


def makeTSV(items):
    txt = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"
    for item in items:
        if item['data']['itemType'] in ['webpage', 'encyclopediaArticle', 'blogPost']:
            txt += getDataFromWebPage(item)
        elif item['data']['itemType'] == 'attachment':
            #with open('tmp/' + item['data']['title'], 'wb') as f:
            #    f.write(zot.file(item['data']['key']))
            print(item)
        else:
            print("??")
        #print(item['data']['itemType'])
    with open('output.tsv', 'w') as f:
        f.write(txt)

print("Id:")
id = input()
zot = zotero.Zotero(id, 'user')
print("Items (i)/ Collection (c)")
t = input()
if t == 'i':
    print('Search :')
    search = input()
    zot.add_parameters(q=search)
    items = zot.top()

else:
    docs = zot.collections()
    tmp = {}
    print('Collection :')
    for doc in docs:
        tmp[doc['data']['name']] = doc['data']['key']
        print(doc['data']['name'])
    print("choose collection")
    col = input()
    items = []
    for elem in col.split(' '):
        items += zot.collection_items(tmp[elem])
    
txt = makeTSV(items)



    


